pypilist
========

    List packages in PyPI.

Install
-------

::

    $ pip install pypilist

Usage
-----

.. code:: python

     >> import pypilist
     >> pypilist.show()     # Prints out the list of all the packages
     >> pypilist.list()     # Returns a json of all the packages

As a CLI app
~~~~~~~~~~~~

::

    $ pypilist

Contribute
==========

If you want to add features, improve them, or report issues, feel free
to send a pull request.

License
=======

MIT © `Harsha Srinivas`_

.. _Harsha Srinivas: https://harshasrinivas.me
